@@ -383,7 +383,7 @@ class Database(object):
                    where owner = '{}' and table_name='{}' \
                    order by column_id".format(dblink_txt, owner.upper(),
                                               table.upper())
-        columns = [column for column, in self.get_one(sql)]
+        columns = [column for column, in self.get_all(sql)]
         return columns
 
     def get_column_information(self, column, table, owner=None,
@@ -422,58 +422,7 @@ class Database(object):
         param = {'column': column, 'length': length,
                  'precision': precision, 'scale': scale,
                  'done': done, 'char': char, 'num': num}
-        conv = {
-            ('my', 'date', 'my', 'create'): '{column} {done}',
-            ('my', 'date', 'my', 'query'): "date_format({column}, '%Y%m%d')",
-            ('my', 'date', 'ora', 'create'): '{column} date',
-            ('my', 'date', 'ora', 'query'): column,
-            ('my', 'int', 'my', 'create'): '{column} {done}',
-            ('my', 'int', 'my', 'query'): column,
-            ('my', 'int', 'ora', 'create'): '{column} number({num})',
-            ('my', 'int', 'ora', 'query'): column,
-            ('my', 'bigint', 'my', 'create'): '{column} {done}',
-            ('my', 'bigint', 'my', 'query'): column,
-            ('my', 'bigint', 'ora', 'create'): '{column} number({num})',
-            ('my', 'bigint', 'ora', 'query'): column,
-            ('my', 'double', 'my', 'create'): '{column} {done}',
-            ('my', 'double', 'my', 'query'): column,
-            ('my', 'double', 'ora', 'create'): '{column} number({num})',
-            ('my', 'double', 'ora', 'query'): column,
-            ('my', 'varchar', 'my', 'create'): '{column} {done}',
-            ('my', 'varchar', 'my', 'query'): column,
-            ('my', 'varchar', 'ora', 'create'): '{column} varchar2({char})',
-            ('my', 'varchar', 'ora', 'query'): column,
-            ('ora', 'DATE', 'my', 'create'): '{column} date',
-            ('ora', 'DATE', 'my', 'query'): "to_char({column}, 'YYYYMMDD')",
-            ('ora', 'DATE', 'ora', 'create'): '{column} date',
-            ('ora', 'DATE', 'ora', 'query'): column,
-            ('ora', 'DATE_J', 'my', 'create'): '{column} date',
-            ('ora', 'DATE_J', 'my', 'query'): "to_char(to_date({column}, 'J'), 'YYYYMMDD')",
-            ('ora', 'DATE_J', 'ora', 'create'): '{column} date',
-            ('ora', 'DATE_J', 'ora', 'query'): "to_date({column}, 'J')",
-            ('ora', 'DATETIME', 'my', 'create'): '{column} datetime',
-            ('ora', 'DATETIME', 'my', 'query'): "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
-            ('ora', 'DATETIME', 'ora', 'create'): '{column} date',
-            ('ora', 'DATETIME', 'ora', 'query'): column,
-            ('ora', 'TIMESTAMP(6)', 'my', 'create'): '{column} datetime',
-            ('ora', 'TIMESTAMP(6)', 'my', 'query'): "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
-            ('ora', 'TIMESTAMP(6)', 'ora', 'create'): '{column} date',
-            ('ora', 'TIMESTAMP(6)', 'ora', 'query'): column,
-            ('ora', 'NUMBER', 'my', 'create'): '{column} double',
-            ('ora', 'NUMBER', 'my', 'query'): column,
-            ('ora', 'NUMBER', 'ora', 'create'): '{column} number({precision}, {scale})',
-            ('ora', 'NUMBER', 'ora', 'query'): column,
-            ('ora', 'VARCHAR2', 'my', 'create'): "{column} varchar({length})",
-            ('ora', 'VARCHAR2', 'my', 'query'): 'ltrim(rtrim({column}))',
-            ('ora', 'VARCHAR2', 'ora', 'create'): '{column} varchar2({length})',
-            ('ora', 'VARCHAR2', 'ora', 'query'): column,
-            ('ora', 'CHAR', 'my', 'create'): "{column} varchar({length})",
-            ('ora', 'CHAR', 'my', 'query'): 'ltrim(rtrim({column}))',
-            ('ora', 'CHAR', 'ora', 'create'): '{column} char({length})',
-            ('ora', 'CHAR', 'ora', 'query'): column
-        }
-        resul = {key: conv[(self.engine, type, desti, key)].format(**param)
-                 for key in ('create', 'query')}
+        resul = {key: column for key in ('create', 'query')}
         return resul
 
     def set_statistics(self, table):
